#ifndef NT2_INCLUDE_FUNCTIONS_ISFLOATING_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ISFLOATING_HPP_INCLUDED

#include <nt2/predicates/include/functions/isfloating.hpp>

#endif
